==> web-fw2_2_2.zip: web-fw2_2_2/j2src/weber/org/itscool/weber/tag/IframeTag.java <==
package org.itscool.weber.tag;

import javax.servlet.jsp.JspException;

import org.itscool.commons.util.TagUtil;

/**
 * HTML&lt;iframe&gt;^O𐶐^OłB<BR>
 * namew肵Ȃꍇproperty̒lԂ܂B<BR>
 *isturts̏ꍇStrutsݒt@Cł̃tH[Ɋ֘AÂꂽBean
 * ɑΉvpeB̒lɂȂ܂B)<BR>
 *<BR>
  *yz<BR>
 * <table cellSpacing=0 cellPadding=0 border=1 >
 * <tr>
 *   <td>propertyiK{j</td>
 *   <td>
 *   Tu~bgɑM郊NGXgp[^łBAT[ubgtH[h
 *   ꂽƂnameŎw肳ꂽBeanCX^XɊYvpeBZbg܂B<br>
 *   namew肳ĂȂꍇpropertyɎw肳ꂽlT[o擾܂B<br>
 *   AHTMLnameɂpropertyɎw肵񂪏o͂܂B
 *  ioptionAlinkAimg^O͏j
 *   </td>
 * <tr>
 * <tr>
 *   <td>name</td>
 *   <td>propertyBean̖Ow肵܂B</td>
 * </tr>
 * <tr>
 *   <td>htmlname</td>
 *   <td>
 *   HTMLnamepropertygpȂꍇ́Ahtmlnamenamew肵܂B
 *   ̑w肷HTMLo͎propertył͂Ȃhtmlname̒lnameƂďo͂܂B
 *   </td>
 * </tr>
 * <tr>
 *   <td>value</td>
 *   <td>̃R|[lgɃZbg鏉l</td>
 * </tr>
 * <tr>
 *   <td>style</td>
 *   <td>̃R|[lg̃X^C</td>
 * </tr>
 * <tr>
 *   <td>scope</td>
 *   <td>propertỹXR[v</td>
 * </tr>
 * <tr>
 *   <td>readonly</td>
 *   <td>̃R|[lg̓ǎ摮itruȅꍇ͓ǎpj</td>
 * </tr>
 * <tr>
 *   <td>disabled</td>
 *   <td>̃R|[lg̎gpۑifalsȅꍇ͎gpsj</td>
 * </tr>
 * <tr>
 *   <td>csclass</td>
 *   <td>̃R|[lgɎw肷X^CV[g</td>
 * </tr>
 * <tr>
 *   <td>
 *   onblur<br>
 *   onchange<br>
 *   onclick<br>
 *   ondblclick<br>
 *   onfocus<br>
 *   onkeydown<br>
 *   onkeypress<br>
 *   onkeyup<br>
 *   onmousedown<br>
 *   onmousemove<br>
 *   onmouseout<br>
 *   onmouseover<br>
 *   onmouseup<br>
 *   </td>
 *   <td>
 *    JavaXNvg
 *   </td>
 * </tr>
 * <tr>
 *   <td>width</td>
 *   <td>̃t[̕w肵܂</td>
 * </tr>
 * <tr>
 *   <td>height</td>
 *   <td>̃t[̍w肵܂</td>
 * </tr>
 * <tr>
 *   <td>targetName</td>
 *   <td>̃t[̃^[Qbg(name)w肵܂</td>
 * </tr>
 * </table>
 * 
 * @author KANO
 * @since jdk1.4.1
 * @version 1.00A 2004/11/1
*/
public class IframeTag extends HtmlTag {
    private String width;
    private String height;
    private String targetName;
    
    /**
     * HTML&lt;iframe&gt;^O𐶐܂<br>
     * scopew肳ĂȂꍇ́ȀŃIuWFNg܂B<br>
     * request, session, context̏
     * @return int
    */
    public int doStartTag() throws JspException {
		String result =
			(String)TagUtil.findProperty(pageContext, name, property, scope);
			
        StringBuffer inputTag = new StringBuffer("<iframe ");
		if( htmlname != null && htmlname.length() > 0 ){
			inputTag.append( TagUtil.createAttribute("name", htmlname) );
		}else{
			inputTag.append( TagUtil.createAttribute("name", property) );
		}
        inputTag.append(TagUtil.createAttribute("src", result));
        inputTag.append(TagUtil.createAttribute("width", width));
        inputTag.append(TagUtil.createAttribute("height", height));
		inputTag.append(TagUtil.createAttribute("style", style));
		inputTag.append(TagUtil.createBoolAttribute("readonly", readonly));
		inputTag.append(TagUtil.createBoolAttribute("disabled", disabled));
		inputTag.append(TagUtil.createBoolAttribute("class", csClass));
        inputTag.append(this.createJavaScriptTag());
        inputTag.append("></iframe>");

        try {
            pageContext.getOut().print(inputTag.toString());
        } catch (Exception e) {
            throw new JspException(e.getMessage());
        }

        return SKIP_BODY;
    }

    public int doEndTag() {
        return EVAL_PAGE;
    }

    /**
     * @return IFrame̍
     */
    public String getHeight() {
        return height;
    }

    /**
     * @return IFrame̕
     */
    public String getWidth() {
        return width;
    }

    /**
     * @param string IFrame̍
     */
    public void setHeight(String string) {
        height = string;
    }

    /**
     * @param string IFrame̕
     */
    public void setWidth(String string) {
        width = string;
    }

    /**
     * @return ^[Qbg
     */
    public String getTargetName() {
        return targetName;
    }

    /**
     * @param string ^[Qbg
     */
    public void setTargetName(String string) {
        targetName = string;
    }

}

==> web-fw3_0_2.zip: web-fw3_0_2/j2src/weber/org/itscool/weber/tag/IframeTag.java <==
package org.itscool.weber.tag;

import javax.servlet.jsp.JspException;

import org.itscool.commons.util.JspTagUtil;

/**
 * HTML&lt;iframe&gt;^O𐶐^OłB<BR>
 * namew肵Ȃꍇproperty̒lԂ܂B<BR>
 *isturts̏ꍇStrutsݒt@Cł̃tH[Ɋ֘AÂꂽBean
 * ɑΉvpeB̒lɂȂ܂B)<BR>
 *<BR>
  *yz<BR>
 * <table cellSpacing=0 cellPadding=0 border=1 >
 * <tr>
 *   <td>propertyiK{j</td>
 *   <td>
 *   Tu~bgɑM郊NGXgp[^łBAT[ubgtH[h
 *   ꂽƂnameŎw肳ꂽBeanCX^XɊYvpeBZbg܂B<br>
 *   namew肳ĂȂꍇpropertyɎw肳ꂽlT[o擾܂B<br>
 *   AHTMLnameɂpropertyɎw肵񂪏o͂܂B
 *  ioptionAlinkAimg^O͏j
 *   </td>
 * <tr>
 * <tr>
 *   <td>name</td>
 *   <td>propertyBean̖Ow肵܂B</td>
 * </tr>
 * <tr>
 *   <td>htmlname</td>
 *   <td>
 *   HTMLnamepropertygpȂꍇ́Ahtmlnamenamew肵܂B
 *   ̑w肷HTMLo͎propertył͂Ȃhtmlname̒lnameƂďo͂܂B
 *   </td>
 * </tr>
 * <tr>
 *   <td>value</td>
 *   <td>̃R|[lgɃZbg鏉l</td>
 * </tr>
 * <tr>
 *   <td>style</td>
 *   <td>̃R|[lg̃X^C</td>
 * </tr>
 * <tr>
 *   <td>scope</td>
 *   <td>propertỹXR[v</td>
 * </tr>
 * <tr>
 *   <td>readonly</td>
 *   <td>̃R|[lg̓ǎ摮itruȅꍇ͓ǎpj</td>
 * </tr>
 * <tr>
 *   <td>disabled</td>
 *   <td>̃R|[lg̎gpۑifalsȅꍇ͎gpsj</td>
 * </tr>
 * <tr>
 *   <td>csclass</td>
 *   <td>̃R|[lgɎw肷X^CV[g</td>
 * </tr>
 * <tr>
 *   <td>
 *   onblur<br>
 *   onchange<br>
 *   onclick<br>
 *   ondblclick<br>
 *   onfocus<br>
 *   onkeydown<br>
 *   onkeypress<br>
 *   onkeyup<br>
 *   onmousedown<br>
 *   onmousemove<br>
 *   onmouseout<br>
 *   onmouseover<br>
 *   onmouseup<br>
 *   </td>
 *   <td>
 *    JavaXNvg
 *   </td>
 * </tr>
 * <tr>
 *   <td>width</td>
 *   <td>̃t[̕w肵܂</td>
 * </tr>
 * <tr>
 *   <td>height</td>
 *   <td>̃t[̍w肵܂</td>
 * </tr>
 * <tr>
 *   <td>targetName</td>
 *   <td>̃t[̃^[Qbg(name)w肵܂</td>
 * </tr>
 * </table>
 * 
 * @author KANO
 * @since jdk1.4.1
 * @version 1.00A 2004/11/1
*/
public class IframeTag extends HtmlTag {
    private String width;
    private String height;
    private String targetName;
    
    /**
     * HTML&lt;iframe&gt;^O𐶐܂<br>
     * scopew肳ĂȂꍇ́ȀŃIuWFNg܂B<br>
     * request, session, context̏
     * @return int
    */
    public int doStartTag() throws JspException {
		String result =
			(String)JspTagUtil.findProperty(pageContext, name, property, scope);
			
        StringBuffer inputTag = new StringBuffer("<iframe ");
		if( htmlname != null && htmlname.length() > 0 ){
			inputTag.append( JspTagUtil.createAttribute("name", htmlname) );
		}else{
			inputTag.append( JspTagUtil.createAttribute("name", property) );
		}
        inputTag.append(JspTagUtil.createAttribute("src", result));
        inputTag.append(JspTagUtil.createAttribute("width", width));
        inputTag.append(JspTagUtil.createAttribute("height", height));
		inputTag.append(JspTagUtil.createAttribute("style", style));
		inputTag.append(JspTagUtil.createBoolAttribute("readonly", readonly));
		inputTag.append(JspTagUtil.createBoolAttribute("disabled", disabled));
		inputTag.append(JspTagUtil.createBoolAttribute("class", csClass));
        inputTag.append(this.createJavaScriptTag());
        inputTag.append("></iframe>");

        try {
            pageContext.getOut().print(inputTag.toString());
        } catch (Exception e) {
            throw new JspException(e.getMessage());
        }

        return SKIP_BODY;
    }

    public int doEndTag() {
        return EVAL_PAGE;
    }

    /**
     * @return IFrame̍
     */
    public String getHeight() {
        return height;
    }

    /**
     * @return IFrame̕
     */
    public String getWidth() {
        return width;
    }

    /**
     * @param string IFrame̍
     */
    public void setHeight(String string) {
        height = string;
    }

    /**
     * @param string IFrame̕
     */
    public void setWidth(String string) {
        width = string;
    }

    /**
     * @return ^[Qbg
     */
    public String getTargetName() {
        return targetName;
    }

    /**
     * @param string ^[Qbg
     */
    public void setTargetName(String string) {
        targetName = string;
    }

}
